Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(19)

Unified Diff: pkg/analysis_server/test/integration/completion/test_all.dart

Issue 458453003: Split up server_domain_int_test.dart; regularize integration test directories. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Update status file Created 6 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: pkg/analysis_server/test/integration/completion/test_all.dart
diff --git a/pkg/analysis_server/test/edit/test_all.dart b/pkg/analysis_server/test/integration/completion/test_all.dart
similarity index 57%
copy from pkg/analysis_server/test/edit/test_all.dart
copy to pkg/analysis_server/test/integration/completion/test_all.dart
index 7c513b6d9788419cee1f719e51beda50997494e4..dc3e046e454e17060a8bf44b3643d3d31bf1f268 100644
--- a/pkg/analysis_server/test/edit/test_all.dart
+++ b/pkg/analysis_server/test/integration/completion/test_all.dart
@@ -2,20 +2,18 @@
// for details. All rights reserved. Use of this source code is governed by a
// BSD-style license that can be found in the LICENSE file.
-library test.edit.all;
+library test.integration.completion.all;
import 'package:unittest/unittest.dart';
-import 'edit_domain_test.dart' as domain_edit_test;
-import 'fix_test.dart' as fix_test;
+import 'get_suggestions_test.dart' as get_suggestions_test;
/**
* Utility for manually running all tests.
*/
main() {
groupSep = ' | ';
- group('edit', () {
- domain_edit_test.main();
- fix_test.main();
+ group('completion', () {
+ get_suggestions_test.main();
});
-}
+}

Powered by Google App Engine
This is Rietveld 408576698
@@ -2,20 +2,18 @@
/**
- * Utility for manually running all tests.
+ * Utility for manually running all integration tests.
*/
main() {